@@ -135,7 +135,7 @@ try
         // Code copied from ReservoirPropertyCommon.hpp for file reading
         std::ifstream rl(rock_list.c_str());
         if (!rl) {
-            OPM_THROW(std::runtime_error, "Could not open file " << rock_list);
+            OPM_THROW(std::runtime_error, "Could not open file " + rock_list);
         }
         int num_rocks = -1;
         rl >> num_rocks;
@@ -156,7 +156,7 @@ try
 
             std::ifstream rock_stream(rockfilename.c_str());
             if (!rock_stream) {
-                OPM_THROW(std::runtime_error, "Could not open file " << rockfilename);
+                OPM_THROW(std::runtime_error, "Could not open file " + rockfilename);
             }
             
             if (! anisorocks) { //Isotropic input rocks (Sw Krw Kro J)
@@ -184,8 +184,11 @@ try
                 rocksatendpoints_[i][0] = Jtmp.getMinimumX().first;
                 rocksatendpoints_[i][1] = Jtmp.getMaximumX().first;
                 if (rocksatendpoints_[i][0] < 0 || rocksatendpoints_[i][0] > 1) {
-                    OPM_THROW(std::runtime_error, "Minimum rock saturation (" << rocksatendpoints_[i][0] << ") not sane for rock " 
-                          << rockfilename << "." << std::endl << "Did you forget to specify anisotropicrocks=true ?");  
+                    OPM_THROW(std::runtime_error,
+                              "Minimum rock saturation (" +
+                              std::to_string(rocksatendpoints_[i][0]) +
+                              ") not sane for rock "  + rockfilename +
+                              ".\nDid you forget to specify anisotropicrocks=true ?");
                 }
             }
             else { //Anisotropic input rocks (Pc Sw Krxx Kryy Krzz)
